@@ -5,32 +5,40 @@
 #ifndef SLIDESHOWSCREENSAVER_H
 #define SLIDESHOWSCREENSAVER_H
 
+#include <QAbstractNativeEventFilter>
 #include <QWidget>
 #include <QMap>
 
-class SlideshowScreenSaver : public QWidget
+class SlideshowScreenSaver : public QWidget, public QAbstractNativeEventFilter
 {
     Q_OBJECT
 public:
     explicit SlideshowScreenSaver(bool subWindow = false, QWidget *parent = nullptr);
     ~SlideshowScreenSaver() override;
 
+    bool nativeEventFilter(const QByteArray &eventType, void *message, long *result) override;
+    void init();
 private slots:
     void onUpdateImage();
 
 protected:
     void paintEvent(QPaintEvent *event) override;
+    void closeEvent(QCloseEvent *event) override;
+
+    QSize mapFromHandle(const QSize &handleSize);
 
 private:
     void showDefaultBlack(QPaintEvent *event);
     void randomImageIndex();
     void loadSlideshowImages();
-    void init();
+    void initPixMap();
     void nextValidPath();
     void filterInvalidFile(const QString &path);
+    void scaledPixmap();
 
 private:
     QScopedPointer<QPixmap> m_pixmap;
+    QScopedPointer<QPixmap> m_scaledPixmap;
     QScopedPointer<QTimer> m_timer;
 
     QString m_path;   // 图片路径
