@@ -31,6 +31,18 @@
 #include <X11/extensions/scrnsaver.h>
 #include <X11/extensions/shape.h>
 
+#ifdef COMPILE_ON_V23
+#   define SYSTEMPOWER_SERVICE "org.deepin.dde.Power1"
+#   define SYSTEMPOWER_PATH "/org/deepin/dde/Power1"
+#   define LOCKFRONT_SERVICE "org.deepin.dde.LockFront1"
+#   define LOCKFRONT_PATH "/org/deepin/dde/LockFront1"
+#else
+#   define SYSTEMPOWER_SERVICE "com.deepin.daemon.Power"
+#   define SYSTEMPOWER_PATH "/com/deepin/daemon/Power"
+#   define LOCKFRONT_SERVICE "com.deepin.dde.lockFront"
+#   define LOCKFRONT_PATH "/com/deepin/dde/lockFront"
+#endif
+
 struct xcb_screensaver_notify_event
 {
     uint8_t      response_type;
@@ -110,8 +122,8 @@ DBusScreenSaver::DBusScreenSaver(QObject *parent)
 
     connect(&m_autoQuitTimer, &QTimer::timeout, this, &QCoreApplication::quit);
 
-    QDBusConnection::sessionBus().connect("com.deepin.daemon.Power",
-                                          "/com/deepin/daemon/Power",
+    QDBusConnection::sessionBus().connect(SYSTEMPOWER_SERVICE,
+                                          SYSTEMPOWER_PATH,
                                           "org.freedesktop.DBus.Properties",
                                           "PropertiesChanged",
                                           this, SLOT(onDBusPropertyChanged(QString,QVariantMap,QDBusMessage)));
@@ -345,8 +357,8 @@ void DBusScreenSaver::Stop(bool lock)
     // 只在由窗口自己唤醒时才会触发锁屏
     if (m_lockScreenAtAwake && !m_lockScreenTimer.isActive()
             && (lock || qobject_cast<ScreenSaverWindow*>(sender()))) {
-        QDBusInterface lockDBus("com.deepin.dde.lockFront", "/com/deepin/dde/lockFront",
-                                "com.deepin.dde.lockFront");
+        QDBusInterface lockDBus(LOCKFRONT_SERVICE, LOCKFRONT_PATH,
+                                LOCKFRONT_SERVICE);
 
         // 通过DBus拉起锁屏程序
         lockDBus.call("Show");
@@ -394,16 +406,16 @@ QStringList DBusScreenSaver::allScreenSaver() const
 
 int DBusScreenSaver::batteryScreenSaverTimeout() const
 {
-    QDBusInterface remoteApp( "com.deepin.daemon.Power", "/com/deepin/daemon/Power",
-                              "com.deepin.daemon.Power" );
+    QDBusInterface remoteApp( SYSTEMPOWER_SERVICE, SYSTEMPOWER_PATH,
+                              SYSTEMPOWER_SERVICE );
 
     return remoteApp.property("BatteryScreensaverDelay").toInt();
 }
 
 int DBusScreenSaver::linePowerScreenSaverTimeout() const
 {
-    QDBusInterface remoteApp( "com.deepin.daemon.Power", "/com/deepin/daemon/Power",
-                              "com.deepin.daemon.Power" );
+    QDBusInterface remoteApp( SYSTEMPOWER_SERVICE, SYSTEMPOWER_PATH,
+                              SYSTEMPOWER_SERVICE );
 
     return remoteApp.property("LinePowerScreensaverDelay").toInt();
 }
@@ -420,16 +432,16 @@ bool DBusScreenSaver::isRunning() const
 
 void DBusScreenSaver::setBatteryScreenSaverTimeout(int batteryScreenSaverTimeout)
 {
-    QDBusInterface remoteApp( "com.deepin.daemon.Power", "/com/deepin/daemon/Power",
-                              "com.deepin.daemon.Power" );
+    QDBusInterface remoteApp( SYSTEMPOWER_SERVICE, SYSTEMPOWER_PATH,
+                              SYSTEMPOWER_SERVICE );
 
     remoteApp.setProperty("BatteryScreensaverDelay", batteryScreenSaverTimeout);
 }
 
 void DBusScreenSaver::setLinePowerScreenSaverTimeout(int linePowerScreenSaverTimeout)
 {
-    QDBusInterface remoteApp( "com.deepin.daemon.Power", "/com/deepin/daemon/Power",
-                              "com.deepin.daemon.Power" );
+    QDBusInterface remoteApp( SYSTEMPOWER_SERVICE, SYSTEMPOWER_PATH,
+                              SYSTEMPOWER_SERVICE );
 
     remoteApp.setProperty("LinePowerScreensaverDelay", linePowerScreenSaverTimeout);
 }
