@@ -1,10 +1,10 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="zh_CN" sourcelanguage="en">
+<TS version="2.1" language="en" sourcelanguage="en">
 <context>
     <name>SelectPathWidget</name>
     <message>
-        <location filename="../selectpathwidget.cpp" line="34"/>
+        <location filename="../selectpathwidget.cpp" line="33"/>
         <location filename="../selectpathwidget.cpp" line="65"/>
         <source>Picture path</source>
         <translation>Picture path</translation>
@@ -15,4 +15,17 @@
         <translation>Select a path of pictures</translation>
     </message>
 </context>
+<context>
+    <name>TimeIntervalWidget</name>
+    <message>
+        <location filename="../timeintervalwidget.cpp" line="32"/>
+        <source>Time interval(s)</source>
+        <translation>Time interval(s)</translation>
+    </message>
+    <message>
+        <location filename="../timeintervalwidget.cpp" line="34"/>
+        <source>Range</source>
+        <translation>Range</translation>
+    </message>
+</context>
 </TS>
